
Changelog
=========

15.02.2022: 0.1.0 added prediction feature, web-app, geo-localization and gpu/cpu-detection estimation
26.06.2021: 0.0.7 put assumptions as self members to allow manual modifications
18.06.2020: 0.0.6 update README.rst
11.06.2020: 0.0.5 add number of processors (0.0.4 failed)
08.06.2020: 0.0.3 added bonus.py carbon impact statement
07.06.2020: 0.0.2 added communication costs and cleaned src/
21.05.2020: 0.0.1 deployment on PypI and integration with Alg-E
2020-05-14: 0.0.0 first release on PyPI